pub struct SocketConfiguration { /* private fields */ }This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Implementations
Sourceimpl SocketConfiguration
impl SocketConfiguration
Sourcepub fn recv_buffer_size(self, size: usize) -> Self
๐Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub fn recv_buffer_size(self, size: usize) -> Self
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Sets the receive buffer size for the socket (no effect on windows/ios).
Note: On Linux the kernel will double the value you specify.
For example, if you specify 16MB, the kernel will configure the
socket to use 32MB.
See: https://man7.org/linux/man-pages/man7/socket.7.html: SO_RCVBUF
Sourcepub fn send_buffer_size(self, size: usize) -> Self
๐Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub fn send_buffer_size(self, size: usize) -> Self
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Sets the send buffer size for the socket (no effect on windows/ios)
Note: On Linux the kernel will double the value you specify.
For example, if you specify 16MB, the kernel will configure the
socket to use 32MB.
See: https://man7.org/linux/man-pages/man7/socket.7.html: SO_SNDBUF
Sourcepub fn set_non_blocking(self, non_blocking: bool) -> Self
๐Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub fn set_non_blocking(self, non_blocking: bool) -> Self
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Configure the socket for non-blocking IO